<?php

declare(strict_types = 1);

namespace Drupal\Tests\paragraphs_usage\Functional;

/**
 * Test paragraphs usage in Content Types.
 *
 * @group paragraphs_usage
 */
class ParagraphsUsageContentTypesTest extends ParagraphsUsageTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'node',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->loginAsAdmin([
      'administer content types',
      'administer node fields',
      'administer node form display',
    ]);
  }

  /**
   * Check if paragraph is used in article content type.
   */
  public function testCheckIfUsed() {
    $this->createContentType([
      'type' => 'article',
      'name' => 'article',
    ]);
    $this->addParagraphsType('test_paragraphs');
    $this->addParagraphsField('article', 'test_paragraphs', 'node');

    $this->drupalGet('admin/structure/paragraphs_type/test_paragraphs/usage');
    $this->assertSession()->pageTextContains('article');

  }

  /**
   * Check if paragraph is not used in page content type.
   */
  public function testCheckIfNotUsed() {
    $this->createContentType([
      'type' => 'article',
      'name' => 'article',
    ]);
    $this->createContentType([
      'type' => 'page',
      'name' => 'page',
    ]);

    $this->addParagraphsType('test_paragraphs');
    $this->addParagraphsField('article', 'test_paragraphs', 'node');

    $this->drupalGet('admin/structure/paragraphs_type/test_paragraphs/usage');
    $this->assertSession()->pageTextNotContains('page');
  }

  /**
   * Check if paragraph is not used in any content type.
   */
  public function testCheckIsEmpty() {
    $this->createContentType([
      'type' => 'article',
      'name' => 'article',
    ]);
    $this->addParagraphsType('test_paragraphs');

    $this->drupalGet('admin/structure/paragraphs_type/test_paragraphs/usage');
    $this->assertSession()->pageTextContains('This paragraph is not used in any content type.');
  }

  /**
   * Check if paragraph don't exist.
   */
  public function testCheckIfParagraphDontExist() {
    $this->drupalGet('admin/structure/paragraphs_type/test_paragraphs/usage');
    $this->assertSession()->statusCodeEquals(404);
  }

  /**
   * Check if Usage link in exist in paragraph's tabs.
   */
  public function testIfTabExist() {
    $this->addParagraphsType('test_paragraphs');

    $this->drupalGet('admin/structure/paragraphs_type/test_paragraphs');
    $this->assertSession()
      ->elementExists('xpath', '//li//a[contains(@href, "/admin/structure/paragraphs_type/test_paragraphs/usage")]');
  }

}
